@@ -1,8 +1,8 @@
 import web
 
-import sapi.config.server
+import sapi.config.general
 import sapi.config.urls
 
-web.config.debug = sapi.config.server.IS_DEBUG
+web.config.debug = sapi.config.general.IS_DEBUG
 
 app = web.application(sapi.config.urls.URLS, locals())
